<?php
/**
 * Initialize the custom theme options.
 */
add_action( 'admin_init', 'diux_custom_theme_options' );

/**
 * Build the custom settings & update OptionTree.
 */
function diux_custom_theme_options() {
  
  /* OptionTree is not loaded yet */
  if ( ! function_exists( 'ot_settings_id' ) )
    return false;
    
  /**
   * Get a copy of the saved settings array. 
   */
  $saved_settings = get_option( ot_settings_id(), array() );
  
  /**
   * Custom settings array that will eventually be 
   * passes to the OptionTree Settings API Class.
   */
  $custom_settings = array( 
    'contextual_help' => array( 
      'sidebar'       => ''
    ),
    'sections'        => array( 
      array(
        'id'          => 'general',
        'title'       => esc_html__('General Setting', 'diux' )
      ),
      array(
        'id'          => 'slider_sectio',
        'title'       => esc_html__('Slider Setting', 'diux' )
      ),
	  array(
        'id'          => 'video_bg_setting_section',
        'title'       => esc_html__('Video Background Setting', 'diux' )
      ),
	  array(
        'id'          => 'yt_bg_setting_section',
        'title'       => esc_html__('Youtube Background Setting', 'diux' )
      ),
	  array(
        'id'          => 'sections_setting',
        'title'       => esc_html__('Sections Setting', 'diux' )
      ),
      array(
        'id'          => 'parallax_section_big_background_image',
        'title'       => esc_html__('Big Background Image', 'diux' )
      ),
	  array(
        'id'          => 'footer_section',
        'title'       => esc_html__('Footer Setting', 'diux' )
      ),
	  
	  array(
        'id'          => 'custom_layout_sec',
        'title'       => esc_html__('Homepage Custom Layout', 'diux' )
      ),
	  
    ),
    'settings'        => array( 

	  array(
        'id'          => 'style_tab',
        'label'       => esc_html__('Style Setting', 'diux' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'tab',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'color_general',
        'label'       => esc_html__('Color Scheme', 'diux' ),
        'desc'        => esc_html__('Pick your color scheme. Default color is #000000', 'diux' ),
        'std'         => '',
        'type'        => 'colorpicker',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'color_scheme',
        'label'       => esc_html__('Hyperlink Color', 'diux' ),
        'desc'        => esc_html__('Pick your color for hyperlink. Default color is black #aaaaaa', 'diux' ),
        'std'         => '',
        'type'        => 'colorpicker',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'custom_hovers',
        'label'       => esc_html__('Hyperlink color on hover state', 'diux' ),
        'desc'        => esc_html__('Pick your color for hover state in hyperlink. Default color is #000000', 'diux' ),
        'std'         => '',
        'type'        => 'colorpicker',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'heading_color',
        'label'       => esc_html__('Color on Heading', 'diux' ),
        'desc'        => esc_html__('Pick your color for heading text. Default color is black #000000', 'diux' ),
        'std'         => '',
        'type'        => 'colorpicker',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'general_color',
        'label'       => esc_html__('Color on General Paragraph', 'diux' ),
        'desc'        => esc_html__('Pick your color for general paragraph text. Default color is black #939393', 'diux' ),
        'std'         => '',
        'type'        => 'colorpicker',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),

	  array(
        'id'          => 'footer_color',
        'label'       => esc_html__('Footer Background color', 'diux' ),
        'desc'        => esc_html__('Pick your background color for footer. Default color is black #000000', 'diux' ),
        'std'         => '',
        'type'        => 'colorpicker',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'stick_menu',
        'label'       => esc_html__('Sticky Menu Background color', 'diux' ),
        'desc'        => esc_html__('Pick your background color for sticky menu. Default color is #000000', 'diux' ),
        'std'         => '',
        'type'        => 'colorpicker',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'logo_tab',
        'label'       => esc_html__('Logo', 'diux' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'tab',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'logo_img',
        'label'       => esc_html__('Logo Upload', 'diux' ),
        'desc'        => esc_html__('Upload your logo here.<br> Recommended size 185x60px', 'diux' ),
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  
      array(
        'id'          => 'favicon_logo',
        'label'       => esc_html__('Favicon Logo', 'diux' ),
        'desc'        => esc_html__('Upload your favicon here. Recommended size 30x30px', 'diux' ),
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'touch_logo',
        'label'       => esc_html__('Touch Logo', 'diux' ),
        'desc'        => esc_html__('Upload your touch logo here. Recommended size 129x129px', 'diux' ),
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'preload_tab',
        'label'       => esc_html__('Preloader', 'diux' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'tab',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'preloader_set',
        'label'       => esc_html__('Preloader Setting', 'diux' ),
        'desc'        => esc_html__('Choose Loader setting', 'diux' ),
        'std'         => '',
        'type'        => 'select',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and',
        'choices'     => array( 
          array(
            'value'       => 'show_home',
            'label'       => esc_html__('Show in Homepage only', 'diux' ),
            'src'         => ''
          ),
          array(
            'value'       => 'show_all',
            'label'       => esc_html__('Show in All pages', 'diux' ),
            'src'         => ''
          ),
          array(
            'value'       => 'hide_in_all',
            'label'       => esc_html__('Hide in All Pages', 'diux' ),
            'src'         => ''
          )
        )
      ),
      array(
        'id'          => 'loader_logo',
        'label'       => esc_html__('Preloader Logo Image', 'diux' ),
        'desc'        => esc_html__('Insert preloader logo image here.', 'diux' ),
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'loader_image',
        'label'       => esc_html__('Preloader Image', 'diux' ),
        'desc'        => esc_html__('Upload your preloader image here<br />
Recommended size 128x128px', 'diux' ),
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'loader_color',
        'label'       => esc_html__('Preloader Background Color', 'diux' ),
        'desc'        => esc_html__('Choose your background color for preloader', 'diux' ),
        'std'         => '',
        'type'        => 'colorpicker',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  
	  
      array(
        'id'          => 'slider_list',
        'label'       => esc_html__('Homepage Slider List', 'diux' ),
        'desc'        => esc_html__('Create your slider list for main/homepage slider.<br/> For homepage with video/youtube background <b>the slider images will appear on touch devices</b> (replacing the video/youtube video).', 'diux' ),
        'std'         => '',
        'type'        => 'list-item',
        'section'     => 'slider_sectio',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and',
        'settings'    => array( 

          array(
            'id'          => 'slider_image',
            'label'       => esc_html__('Slider Image', 'diux' ),
            'desc'        => esc_html__('Upload your slider image here. You can leave it blank if you are using homepage background video template.', 'diux' ),
            'std'         => '',
            'type'        => 'upload',
            'rows'        => '',
            'post_type'   => '',
            'taxonomy'    => '',
            'min_max_step'=> '',
            'class'       => '',
            'condition'   => '',
            'operator'    => 'and'
          ),
          array(
            'id'          => 'bottom_text',
            'label'       => esc_html__('Slider bottom text', 'diux' ),
            'desc'        => esc_html__('Input your slider small/bottom text here.', 'diux' ),
            'std'         => '',
            'type'        => 'textarea-simple',
            'rows'        => '',
            'post_type'   => '',
            'taxonomy'    => '',
            'min_max_step'=> '',
            'class'       => '',
            'condition'   => '',
            'operator'    => 'and'
          ),
		  		  array(
            'id'          => 'slider_link',
            'label'       => esc_html__( 'Slider Link Button', 'diux' ),
            'desc'        => esc_html__( 'Input your slider button link here( leave it blank if you don\'t want it)', 'diux' ),
            'std'         => '',
            'type'        => 'text',
            'rows'        => '',
            'post_type'   => '',
            'taxonomy'    => '',
            'min_max_step'=> '',
            'class'       => '',
            'condition'   => '',
            'operator'    => 'and'
          ),
		  
        )
      ),
      array(
        'id'          => 'slider_delay',
        'label'       => esc_html__('Homepage Slider Delay', 'diux' ),
        'desc'        => esc_html__('Set your slider delay here.', 'diux' ),
        'std'         => '10000',
        'type'        => 'numeric-slider',
        'section'     => 'slider_sectio',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '1,10000,1',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  
	   array(
        'id'          => 'fot_text_tab',
        'label'       => esc_html__('Footer Text', 'diux' ),
        'std'         => '',
        'type'        => 'tab',
        'section'     => 'footer_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'fot_text',
        'label'       => esc_html__('Footer Text', 'diux' ),
        'desc'        => esc_html__('Input footer text here. You can use HTML tag here.', 'diux' ),
        'std'         => '',
        'type'        => 'textarea-simple',
		'rows'        => '3',
        'section'     => 'footer_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'fot_soc_tab',
        'label'       => esc_html__('Footer Social Icon', 'diux' ),
        'std'         => '',
        'type'        => 'tab',
        'section'     => 'footer_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	   array(
        'id'          => 'fb_foot',
        'label'       => esc_html__('Facebook Link', 'diux' ),
        'desc'        => esc_html__('Input facebook link here', 'diux' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'footer_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'gp_foot',
        'label'       => esc_html__('Google Plus Link', 'diux' ),
        'desc'        => esc_html__('Input google plus link here', 'diux' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'footer_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'twit_foot',
        'label'       => esc_html__('Twitter Link', 'diux' ),
        'desc'        => esc_html__('Input twitter link here', 'diux' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'footer_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'pint_foot',
        'label'       => esc_html__('Pinterest Link', 'diux' ),
        'desc'        => esc_html__('Input pinterest link here', 'diux' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'footer_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'insta_link',
        'label'       => esc_html__('Instagram Link', 'diux' ),
        'desc'        => esc_html__('Input instagram link here', 'diux' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'footer_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'xing_foot',
        'label'       => esc_html__('Xing Link', 'diux' ),
        'desc'        => esc_html__('Input xing link here', 'diux' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'footer_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'foot_as_icon',
        'label'       => esc_html__('Another Social Icon', 'diux' ),
        'desc'        => esc_html__('Create list for another social icon.', 'diux' ),
        'std'         => '',
        'type'        => 'list-item',
        'section'     => 'footer_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and',
        'settings'    => array( 
          array(
            'id'          => 'foot_soc_icon',
            'label'       => esc_html__('Social Icon', 'diux' ),
            'desc'        => esc_html__('Input your social icon here. <br /> You can check <a target="_blank" href="http://fontawesome.io/icons/">Here</a> for icon list. eg. fa-github', 'diux' ),
            'std'         => '',
            'type'        => 'text',
            'rows'        => '',
            'post_type'   => '',
            'taxonomy'    => '',
            'min_max_step'=> '',
            'class'       => '',
            'condition'   => '',
            'operator'    => 'and'
          ),
          array(
            'id'          => 'foot_as_link',
            'label'       => esc_html__('Social Icon Link', 'diux' ),
            'desc'        => esc_html__('Input social icon link here', 'diux' ),
            'std'         => '',
            'type'        => 'text',
            'rows'        => '',
            'post_type'   => '',
            'taxonomy'    => '',
            'min_max_step'=> '',
            'class'       => '',
            'condition'   => '',
            'operator'    => 'and'
          )
        )
      ),
	  array(
        'id'          => 'home_setting',
        'label'       => esc_html__('Home Section Background Setting', 'diux'),
        'desc'        => esc_html__('You can set the slider/video background at slider and video background settings.', 'diux'),
        'std'         => 'slider_bg_home',
        'type'        => 'select',
        'section'     => 'custom_layout_sec',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'choices'     => array( 
          array(
            'value'       => 'slider_bg_home',
            'label'       => esc_html__('Slider Background', 'diux'),
            'src'         => ''
          ),
          array(
            'value'       => 'video_bg_home',
            'label'       => esc_html__('Video Background', 'diux'),
            'src'         => ''
          ),
		  array(
            'value'       => 'youtube_bg_home',
            'label'       => esc_html__('Youtube Video Background', 'diux'),
            'src'         => ''
          )
        ),
      ),
	  array(
        'id'          => 'text_block_video_section',
        'label'       => esc_html__('THE SETTING ONLY FOR VIDEO BACKGROUND IN HOMEPAGE VIDEO TEMPLATE', 'diux' ),
        'desc'        => esc_html__('You can set your video here. This is only affect on homepage with <strong> Homepage Video</strong> template', 'diux' ),
        'std'         => '',
        'type'        => 'textblock-titled',
        'section'     => 'video_bg_setting_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'video_link',
        'label'       => esc_html__('Video Source', 'diux' ),
        'desc'        => esc_html__('Insert your video source here (only directlink). eg. http://yoursite.com/video.mp4', 'diux' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'video_bg_setting_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'video_mute',
        'label'       => esc_html__('Video Mute', 'diux' ),
        'desc'        => esc_html__('You can turn on/off video audio (mute)', 'diux' ),
        'std'         => '',
        'type'        => 'on-off',
        'section'     => 'video_bg_setting_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),

	  array(
        'id'          => 'home_setting_box',
        'label'       => 'box text home setting',
        'desc'        => esc_html__('THIS SETTING ONLY APPLIES ON PAGE WITH  "HOMEPAGE CUSTOM LAYOUT" TEMPLATE','diux'),
        'std'         => '',
        'type'        => 'textblock',
        'section'     => 'custom_layout_sec',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
      array(
        'id'          => 'custom_layout',
        'label'       => esc_html__('Section List','diux'),
        'desc'        => esc_html__('Create your sections list here.<br/> Noted: <b>The title</b> on custom section will be the <b>id/anchor</b> to put in your homepage menu. <br/>
		Make sure <b>the title</b> doesn\'t have <b>space/white area</b> or <b>any special character</b>.','diux'),
        'std'         => '',
        'type'        => 'list-item',
        'section'     => 'custom_layout_sec',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'settings'    => array( 
			array(
            'id'          => 'section_type',
            'label'       => esc_html__('Select Section','diux'),
            'desc'        => esc_html__('Select the section that you want to add in homepage','diux'),
            'std'         => '',
            'type'        => 'select',
            'rows'        => '',
            'post_type'   => '',
            'taxonomy'    => '',
            'min_max_step'=> '',
            'class'       => '',
            'choices'     => array( 
              array(
                'value'       => 'about_content',
                'label'       => esc_html__('About', 'diux'),
                'src'         => ''
              ),
			  array(
                'value'       => 'portfolio_content',
                'label'       => esc_html__('Works Section', 'diux'),
                'src'         => ''
              ),
			  array(
                'value'       => 'team_content',
                'label'       => esc_html__('Team Section', 'diux'),
                'src'         => ''
              ),
			  array(
                'value'       => 'contact_content',
                'label'       => esc_html__('Contact Section', 'diux'),
                'src'         => ''
              ),
			  array(
                'value'       => 'client_content',
                'label'       => esc_html__('Client Section', 'diux'),
                'src'         => ''
              ),
			  array(
                'value'       => 'custom_content',
                'label'       => esc_html__('Custom Section', 'diux'),
                'src'         => ''
              ),
            ),
          ),
			array(
				'id'          => 'custom_section',
				'label'       => esc_html__('Custom Section', 'diux' ),
				'desc'        => esc_html__('Choose your custom section post here.', 'diux' ),
				'std'         => '',
				'type'        => 'custom-post-type-select',
				'section'     => 'custom_layout_sec',
				'rows'        => '',
				'post_type'   => 'custom-section',
				'taxonomy'    => '',
				'min_max_step'=> '',
				'class'       => '',
				'condition'   => 'section_type:is(custom_content)',
				'operator'    => 'and'
			),	
        )
      ),
	  array(
        'id'          => 'section_block_title',
        'label'       => esc_html__('SECTION SETTINGS', 'diux' ),
        'desc'        => esc_html__('You can set up each section in homepage here.', 'diux' ),
        'std'         => '',
        'type'        => 'textblock-titled',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  
	  
	  array(
        'id'          => 'works_portfolio_setting_tab',
        'label'       => esc_html__('Works', 'diux' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'tab',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'port_block',
        'label'       => esc_html__('You can create each portfolio item in portfolio post.', 'diux' ),
        'desc'        => esc_html__('For creating new portfolio item, go to left menu Portfolio -> Add New Portfolio', 'diux' ),
        'std'         => '',
        'type'        => 'textblock-titled',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'works_circle',
        'label'       => esc_html__('Works Black Circle', 'diux' ),
        'desc'        => esc_html__('Insert your text for black circle here. eg. 01.', 'diux' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  
      array(
        'id'          => 'works_big_title',
        'label'       => esc_html__('Works Big Title', 'diux' ),
        'desc'        => esc_html__('Insert your big title for works section here. eg. The Works we\'ve done so far', 'diux' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'works_icon',
        'label'       => esc_html__('Works Icon', 'diux' ),
        'desc'        => esc_html__('IInput your works icon here. <br> You can check <a target="_blank" href="http://fontawesome.io/icons/">Here</a> for icon list. 
		eg. fa-snowflake-o', 'diux' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'sections_setting',
        'rows'        => '3',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'works_all',
        'label'       => esc_html__('Works Filter for all categories', 'diux' ),
        'desc'        => esc_html__('Insert your text for works filter for all categories. The default text is "All"', 'diux' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'sections_setting',
        'rows'        => '3',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  
	   array(
        'id'          => 'client_list_tab',
        'label'       => esc_html__('Client List', 'diux' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'tab',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'client_block',
        'label'       => esc_html__('You can add the background image for client section in Big Background Image.', 'diux' ),
        'desc'        => esc_html__('Go to Theme Options->Big Background Image.', 'diux' ),
        'std'         => '',
        'type'        => 'textblock-titled',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'client_title',
        'label'       => esc_html__('Title for client list', 'diux' ),
        'desc'        => esc_html__('Insert the title for client list here. eg. Our Recent Client', 'diux' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'client_circle',
        'label'       => esc_html__('Client Black Circle', 'diux' ),
        'desc'        => esc_html__('Insert your text for black circle here. eg. 02.', 'diux' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'client_icon',
        'label'       => esc_html__('Client Icon', 'diux' ),
        'desc'        => esc_html__('Input your client icon here. <br> You can check <a target="_blank" href="http://fontawesome.io/icons/">Here</a> for icon list. eg. fa-snowflake-o', 'diux' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),

      array(
        'id'          => 'client_list',
        'label'       => esc_html__('Client List', 'diux' ),
        'desc'        => esc_html__('Create your client list here.', 'diux' ),
        'std'         => '',
        'type'        => 'list-item',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and',
        'settings'    => array( 
          array(
            'id'          => 'client_image',
            'label'       => esc_html__('Client Image', 'diux' ),
            'desc'        => esc_html__('Upload your client images here.', 'diux' ),
            'std'         => '',
            'type'        => 'upload',
            'rows'        => '',
            'post_type'   => '',
            'taxonomy'    => '',
            'min_max_step'=> '',
            'class'       => '',
            'condition'   => '',
            'operator'    => 'and'
          )
        )
      ),

      array(
        'id'          => 'client_list_column',
        'label'       => esc_html__('Client List Column', 'diux' ),
        'desc'        => esc_html__('Select how many columns you want to use for client list. Default is 4 columns.', 'diux' ),
        'std'         => '',
        'type'        => 'select',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and',
        'choices'     => array( 
          array(
            'value'       => 'col_4',
            'label'       => esc_html__('4 Columns', 'diux' ),
            'src'         => ''
          ),
          array(
            'value'       => 'col_3',
            'label'       => esc_html__('3 Columns', 'diux' ),
            'src'         => ''
          ),
          array(
            'value'       => 'col_2',
            'label'       => esc_html__('2 Columns', 'diux' ),
            'src'         => ''
          )
        )
      ), 
	  
	   
	  
	  array(
        'id'          => 'about_section_tab',
        'label'       => esc_html__('About', 'diux' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'tab',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'about_block',
        'label'       => esc_html__('You can create about post in About Us.', 'diux' ),
        'desc'        => esc_html__('For creating about post, go to left menu About Us -> Add New About Us. <br>Only 1 about post will appear in homepage.', 'diux' ),
        'std'         => '',
        'type'        => 'textblock-titled',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'about_circle',
        'label'       => esc_html__('About Black Circle', 'diux' ),
        'desc'        => esc_html__('Insert your text for black circle here. eg. 03.', 'diux' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'about_big_title',
        'label'       => esc_html__('About Title', 'diux' ),
        'desc'        => esc_html__('Insert your title for about section here. eg. About Us', 'diux' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'about_icon',
        'label'       => esc_html__('About Icon', 'diux' ),
        'desc'        => esc_html__('Input your about icon here. <br /> You can check <a target="_blank" href="http://fontawesome.io/icons/">Here</a> for icon list. 
			eg. fa-snowflake-o', 'diux' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  	  array(
        'id'          => 'team_section_tab',
        'label'       => esc_html__('Team', 'diux' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'tab',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  
	  array(
        'id'          => 'team_block',
        'label'       => esc_html__('You can create each team post in Team Posts.', 'diux' ),
        'desc'        => esc_html__('For creating new team post, go to left menu Team Posts -> Add New Team Post', 'diux' ),
        'std'         => '',
        'type'        => 'textblock-titled',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'team2_block',
        'label'       => esc_html__('You can add the background image for team section in Big Background Image.', 'diux' ),
        'desc'        => esc_html__('Go to Theme Options->Big Background Image.', 'diux' ),
        'std'         => '',
        'type'        => 'textblock-titled',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'team_circle',
        'label'       => esc_html__('Team Black Circle', 'diux' ),
        'desc'        => esc_html__('Insert your text for black circle here. eg. 04.', 'diux' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'team_title',
        'label'       => esc_html__('Team Section Title', 'diux' ),
        'desc'        => esc_html__('Insert your title for team section here. eg. Meet the team', 'diux' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'team_icon',
        'label'       => esc_html__('Team icon', 'diux' ),
        'desc'        => esc_html__('Insert your icon for team section here. <br /> You can check <a target="_blank" href="http://fontawesome.io/icons/">Here</a> for icon list. ', 'diux' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  


	  
	  
	 	 

	  
 	   array(
        'id'          => 'contact_section_tab',
        'label'       => esc_html__( 'Contact', 'diux' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'tab',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'contact_block',
        'label'       => esc_html__( 'You can create contact post in contact post.', 'diux' ),
        'desc'        => esc_html__( 'For creating contact post or inserting contact form 7 shortcode, go to left menu Contact Posts -> Add New Contact Post', 'diux' ),
        'std'         => '',
        'type'        => 'textblock-titled',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'contact_circle',
        'label'       => esc_html__( 'Contact Black Circle', 'diux' ),
        'desc'        => esc_html__( 'Insert your text for black circle here. eg. 05.', 'diux' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'contact_big_title',
        'label'       => esc_html__( 'Contact Title', 'diux' ),
        'desc'        => esc_html__( 'Insert your title for contact section here. eg. The Contact', 'diux' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	
	array(
        'id'          => 'contact_icon',
        'label'       => esc_html__( 'Contact Icon', 'diux' ),
        'desc'        => esc_html__( 'Input your contact icon here. <br> You can check <a target="_blank" href="http://fontawesome.io/icons/">Here</a> for icon list. eg. fa-snowflake-o', 'diux' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),

      
	  
	  array(
        'id'          => 'tx_address',
        'label'       => esc_html__( 'Insert Text for Address', 'diux' ),
        'desc'        => esc_html__( 'Insert text for address here. The default text is The Address', 'diux' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  
	  array(
        'id'          => 'map_address',
        'label'       => esc_html__( 'Address', 'diux' ),
        'desc'        => esc_html__( 'Insert your address here. <br/>Leave it blank if you don\'t need it', 'diux' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),

	  array(
        'id'          => 'tx_phone',
        'label'       => esc_html__( 'Insert Text for Phone', 'diux' ),
        'desc'        => esc_html__( 'Insert text for phone here. The default text is The Phone', 'diux' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'map_phone',
        'label'       => esc_html__( 'Phone', 'diux' ),
        'desc'        => esc_html__( 'Insert your phone here. <br/>Leave it blank if you don\'t need it', 'diux' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),

	  array(
        'id'          => 'tx_email',
        'label'       => esc_html__( 'Insert Text for Email', 'diux' ),
        'desc'        => esc_html__( 'Insert text for email here. The default text is The Email', 'diux' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  
	  array(
        'id'          => 'map_email',
        'label'       => esc_html__( 'Email', 'diux' ),
        'desc'        => esc_html__( 'Insert your email here. <br/>Leave it blank if you don\'t need it', 'diux' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  

	 array(
        'id'          => 'parallax_two',
        'label'       => esc_html__('Client List Setting', 'diux' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'tab',
        'section'     => 'parallax_section_big_background_image',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'para2_block',
        'label'       => esc_html__('You can create client list in Section Settings (theme options)', 'diux' ),
        'desc'        => esc_html__('For creating client list, go to left menu Theme Options ->Section Settings ->Client List', 'diux' ),
        'std'         => '',
        'type'        => 'textblock-titled',
        'section'     => 'parallax_section_big_background_image',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'client_bg_img',
        'label'       => esc_html__('Background Image', 'diux' ),
        'desc'        => esc_html__('Upload your background image for client list here.', 'diux' ),
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'parallax_section_big_background_image',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),

	  array(
        'id'          => 'team_bg_setting',
        'label'       => esc_html__('Team List Setting', 'diux' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'tab',
        'section'     => 'parallax_section_big_background_image',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	        
	  array(
        'id'          => 'para3_block',
        'label'       => esc_html__('You can create team list in Section Settings (theme options)', 'diux' ),
        'desc'        => esc_html__('For creating team list, go to left menu Team Posts->Add New Team Post', 'diux' ),
        'std'         => '',
        'type'        => 'textblock-titled',
        'section'     => 'parallax_section_big_background_image',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'team_bg_img',
        'label'       => esc_html__('Team Background Image', 'diux' ),
        'desc'        => esc_html__('Upload your background image for team section here.', 'diux' ),
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'parallax_section_big_background_image',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),

	  
      
     
	  
	  
	  
	  
	  
	  array(
        'id'          => 'text_block_yt_section_rec',
        'label'       => esc_html__('THE SETTING ONLY FOR YOUTUBE VIDEO BACKGROUND IN HOMEPAGE YOUTUBE TEMPLATE', 'diux' ),
        'desc'        => esc_html__('You set your video here. This is only affect on homepage with <strong> Homepage Youtube</strong>', 'diux' ),
        'std'         => '',
        'type'        => 'textblock-titled',
        'section'     => 'yt_bg_setting_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'yt_id',
        'label'       => esc_html__('Youtube Id', 'diux' ),
        'desc'        => esc_html__('Input your youtube ID here. <br /><strong>Remember only input the ID!</strong>. eg. c9MnSeYYtYY', 'diux' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'yt_bg_setting_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	        array(
        'id'          => 'yt_qt',
        'label'       => esc_html__('Youtube Video Quality', 'diux' ),
        'desc'        => esc_html__('Insert your youtube video quality here. <br>You can input <b>small</b>, <b>medium</b>, <b>large</b>, <b>hd720</b>, <b>hd1080</b>, <b>highres</b>. 
		<br> Default value is large', 'diux' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'yt_bg_setting_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'yt_mute',
        'label'       => esc_html__('Youtube Video Mute', 'diux' ),
        'desc'        => esc_html__('You can turn on/off youtube video audio (mute)', 'diux' ),
        'std'         => '',
        'type'        => 'on-off',
        'section'     => 'yt_bg_setting_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
    )
  );
  
  /* allow settings to be filtered before saving */
  $custom_settings = apply_filters( ot_settings_id() . '_args', $custom_settings );
  
  /* settings are not the same update the DB */
  if ( $saved_settings !== $custom_settings ) {
    update_option( ot_settings_id(), $custom_settings ); 
  }
  
  /* Lets OptionTree know the UI Builder is being overridden */
  global $ot_has_custom_theme_options;
  $ot_has_custom_theme_options = true;
  
}